ToolKit class

Constructors

ToolKit()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hide() → void
run(Widget app, {List<Pluggable>? pluginsList, bool? autoCollectLogs}) → void
【app】主应用
show({bool isDarkMode = false}) → void