KitUtils class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

deviceHeight double
设备高度
final
devicePixelRatio double
设备宽高比
final
deviceWidth double
设备宽度
final
instance KitUtils
no setter

Static Methods

copy(BuildContext context, String? text, {String? toastText}) → void
getCachePath() Future<String>
获取app缓存路径
getDeviceInfo() Future<AndroidDeviceInfo>
获取系统信息
getDeviceName() Future<String>
getPackageInfo() Future<PackageInfo>
获取包信息
getPhoneDBPath() Future<String>
获取手机数据库路径
getPhoneDocumentsPath() Future<String>
获取手机本地路径
showToast(BuildContext context, {required String message, bool isError = false}) → void