ProxyUtils class

Properties

hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
no setter
onProxyChanged ↔ dynamic Function(String url, bool enabled)?
getter/setter pair
proxyUrl String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearProxy() Future<void>
清除代理设置
getEffectiveProxyUrl() String
获取当前有效的代理URL(只有启用时才返回)
getProxy(dynamic callback(String)?) Future<String>
getProxyInfo() Map<String, dynamic>
获取代理信息
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProxy(String url, bool enabled) Future<void>
设置代理
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ProxyUtils
no setter