PluginIcons class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- alignRuler → Widget
-
no setter
- appDeviceInfo → Widget
-
no setter
- appLog → Widget
-
no setter
- clear → Widget
-
no setter
- colorPicker → Widget
-
no setter
- database → Widget
-
no setter
- dio → Widget
-
no setter
- fileManager → Widget
-
no setter
- frameRate → Widget
-
no setter
- main → Widget
-
no setter
- performance → Widget
-
no setter
- proxy → Widget
-
no setter
- regular → Widget
-
no setter
- routeHistory → Widget
-
no setter
- widgetDetail → Widget
-
no setter
- widgetInfo → Widget
-
no setter
Constants
- defaultColor → const Color
- iconSize → const double