ToolkitStatusManager class

Properties

ballSize Size
final
hashCode int
The hash code for this object.
no setterinherited
final
minX double
final
positionNotifier ValueNotifier<Offset>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closeMenu() → void
getInitialPosition(BuildContext context) Future<Offset>
getMaxX(BuildContext context) double
getMaxY(BuildContext context) double
getMinY(BuildContext context) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetPosition(BuildContext context) → void
savePosition(Offset position) Future<void>
toggleMenu() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ToolkitStatusManager
no setter